#pragma once

typedef char** MYSQL_ROW;

// possible error codes
#define EXTERNAL_ERROR					-2000
#define CONNECTION_TIMED_OUT			-1001
#define SOCKET_NOT_VALID				-1002
#define SOCKET_CONNECTION_FAILED		-1003
#define MYSQL_NOT_CONNECTED				-1004
#define WRONG_PACKET_DATA				-1005
#define EMPTY_PARAMETER_NOT_ALLOWED		-1006
#define FIELD_NOT_FOUND					-1007
#define ROW_NOT_FOUND					-1008
#define UNKNOWN_FIELD_PARAMETER			-1009
#define NO_SUCH_COLUMN					-1010
#define NO_SUCH_ROW						-1011

// field parameters for mysql_get_field_param() function
#define FIELD_PARAM_CATALOG				1
#define FIELD_PARAM_DB					2
#define FIELD_PARAM_TABLE				3
#define FIELD_PARAM_ORIGTABLE			4
#define FIELD_PARAM_FIELD				5
#define FIELD_PARAM_ORIGFIELD			6
#define FIELD_PARAM_LENGTH				7
#define FIELD_PARAM_TYPE				8
#define FIELD_PARAM_FLAGS				9
#define FIELD_PARAM_DECIMALS			10

// mysql field flags
#define NOT_NULL_FLAG					1		/* Field can't be NULL */
#define PRI_KEY_FLAG					2		/* Field is part of a primary key */
#define UNIQUE_KEY_FLAG					4		/* Field is part of a unique key */
#define MULTIPLE_KEY_FLAG				8		/* Field is part of a key */
#define BLOB_FLAG						16		/* Field is a blob */
#define UNSIGNED_FLAG					32		/* Field is unsigned */
#define ZEROFILL_FLAG					64		/* Field is zerofill */
#define BINARY_FLAG						128		/* Field is binary   */
/* The following are only sent to new clients */
#define ENUM_FLAG						256		/* field is an enum */
#define AUTO_INCREMENT_FLAG				512		/* field is a autoincrement field */
#define TIMESTAMP_FLAG					1024	/* Field is a timestamp */
#define SET_FLAG						2048	/* field is a set */
#define NO_DEFAULT_VALUE_FLAG			4096	/* Field doesn't have default value */
#define NUM_FLAG						32768	/* Field is num (for clients) */

enum enum_field_types { FIELD_TYPE_DECIMAL=0x00,
						FIELD_TYPE_TINY=0x01,
						FIELD_TYPE_SHORT=0x02,
						FIELD_TYPE_LONG=0x03,
						FIELD_TYPE_FLOAT=0x04,
						FIELD_TYPE_DOUBLE=0x05,
						FIELD_TYPE_NULL0x06,
						FIELD_TYPE_TIMESTAMP=0x07,
						FIELD_TYPE_LONGLONG=0x08,
						FIELD_TYPE_INT24=0x09,
						FIELD_TYPE_DATE=0x0a,
						FIELD_TYPE_TIME=0x0b,
						FIELD_TYPE_DATETIME=0x0c,
						FIELD_TYPE_YEAR=0x0d,
						FIELD_TYPE_NEWDATE=0x0e,
						FIELD_TYPE_VARCHAR=0x0f,
                        FIELD_TYPE_BIT=0x10,
                        FIELD_TYPE_NEWDECIMAL=0xf6,
						FIELD_TYPE_ENUM=0xf7,
						FIELD_TYPE_SET=0xf8,
						FIELD_TYPE_TINY_BLOB=0xf9,
						FIELD_TYPE_MEDIUM_BLOB=0xfa,
						FIELD_TYPE_LONG_BLOB=0xfb,
						FIELD_TYPE_BLOB=0xfc,
						FIELD_TYPE_VAR_STRING=0xfd,
						FIELD_TYPE_STRING=0xfe,
						FIELD_TYPE_GEOMETRY=0xff };
